#
# spec file for package tuxpaint-config
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tuxpaint-config
Version:        0.0.13
Release:        2.11
Summary:        Configuration tool for Tux Paint
License:        GPL-2.0+
Group:          Productivity/Graphics/Bitmap Editors
Url:            http://www.tuxpaint.org/
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libpaper-devel
BuildRequires:  xorg-x11-devel
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
Requires:       %{name}-lang = %{version}
Recommends:     tuxpaint
%endif
Source:         %{name}-%{version}.tar.bz2
Patch1:         tuxpaint-config-docpath.patch
Patch2:         tuxpaint-config-desktop.patch
Patch3:         tuxpaint-config-manpage.patch
Patch4:         tuxpaint-config-missing_includes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tux Paint has a rich set of configuration options, controllable via
command-line options or configuration files. This configuration tool
provides a point-and-click interface for administrators to tailor
Tux Paint to suit the needs of their users.

%if 0%{?suse_version}
%{lang_package ca da el en_GB es fr it ja nl nn pt_BR pt_PT ru sk sl son sv uk zh_TW}
%endif

%prep
%setup -q
find . -name CVS | xargs rm -rf
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%build
make  PREFIX="%{_prefix}" X11_ICON_PREFIX=/usr/include/X11/pixmaps/

%install
mkdir -p %{buildroot}/%{_bindir}
make PREFIX="%{buildroot}/%{_prefix}" \
     X11_ICON_PREFIX="%{buildroot}/%{_includedir}/X11/pixmaps/" \
     DOC_PREFIX="%{buildroot}/%{_defaultdocdir}/%{name}" install
install -D -m644 src/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
# desktop file
%if 0%{?suse_version}
%suse_update_desktop_file -n %{name}
%endif
# fix file permissions
find %{buildroot}%_defaultdocdir/%{name} -type f -exec chmod 644 {} \;
find %{buildroot}%{_mandir} -type f -exec chmod 644 {} \;
# reduce space
%if 0%{?suse_version}
%fdupes -s %{buildroot}
strip %{buildroot}/%{_bindir}/tuxpaint-config
%endif
%find_lang %{name}

%clean
rm -rf %{buildroot}

%if 0%{?fedora_version}
%files -f %{name}.lang
%defattr(-,root,root)
%else
%files
%defattr(-,root,root)
%endif
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/tuxpaint-config
%doc %_defaultdocdir/%{name}
%dir %{_includedir}/X11/pixmaps
%{_includedir}/X11/pixmaps/tuxpaint-config.xpm
%{_mandir}/man1/*
%{_datadir}/tuxpaint-config/
%{_datadir}/pixmaps/*.png
%{_datadir}/applications/*.desktop

%if 0%{?suse_version}
%files lang -f %{name}.lang
%defattr(-,root,root)
%if 0%{?suse_version} <= 1130
%defattr(-,root,root)
# unrecogniced locales
%dir %{_datadir}/locale/ach
%dir %{_datadir}/locale/ach/LC_MESSAGES
%dir %{_datadir}/locale/an
%dir %{_datadir}/locale/an/LC_MESSAGES
%dir %{_datadir}/locale/cgg
%dir %{_datadir}/locale/cgg/LC_MESSAGES
%dir %{_datadir}/locale/ff
%dir %{_datadir}/locale/ff/LC_MESSAGES
%dir %{_datadir}/locale/sat
%dir %{_datadir}/locale/sat/LC_MESSAGES
%dir %{_datadir}/locale/son
%dir %{_datadir}/locale/son/LC_MESSAGES
%dir %{_datadir}/locale/vec
%dir %{_datadir}/locale/vec/LC_MESSAGES
%endif
%endif

%changelog
* Fri Dec 26 2014 lars@linux-schulserver.de
- update to 0.0.13:
  + Added "Disable Label tool" option, to match new Tux Paint feature
  + Added options for new languages
  + Added "Accessibility" tab, with options for sticky mouse clicks,
    keyboard-based mouse movement, and on-screen keyboard
    (new features in Tux Paint)
  + Added "Joystick" tab, with options for configuring joystick controls
    (another new feature in Tux Paint)
  + Fixed bug where hitting [Cancel] in file/directory chooser dialogs
    would cause Tux Paint Config. to crash
  + Modularized some of the UI layout code
  + new translations
- refreshed all patches
- added tuxpaint-config-missing_includes.patch
- removed tuxpaint-config-de.po (upstream translation exists now)
* Mon Jul  9 2012 lars@linux-schulserver.de
- fix license to be in SPDX format
* Fri Jun 29 2012 lars@linux-schulserver.de
- added tuxpaint-config-manpage.patch to fix manpage typos
- specfile cleanup
* Sun Jul  3 2011 lars@linux-schulserver.de
- fix build on newer openSUSE distributions (fix language dirs)
* Mon Aug  3 2009 lars@linux-schulserver.de
- update to 0.0.12:
  + Added "Disable Magic controls" option
  + Added "Load all locale fonts" option
  + Added "Save Printer Configuration" option
  + Added translation files
  + Added options for "Asturian", "Shuswap" and "Songhay" languages
- split up lang package
- added german language
* Thu Oct 30 2008 lars@linux-schulserver.de
- fix desktop category
* Wed Oct  1 2008 lars@linux-schulserver.de
- update to 0.0.11:
  + fix desktop icon path
  + "Ojibwe" is the proper spelling of the language;
    changed option in TPC.
- fix desktop entry patch: prefix with X-
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Mar  4 2008 lars@linux-schulserver.de
- update to 0.0.10
  - Added "Allow screensaver" option, to match new
    Tux Paint feature.
  - Added newly supported Tux Paint locales:
    + Australian English
    + Azerbaijani
    + Canadian English
    + Khmer
    + Macedonian
    + Occitan
    + Zapoteco
* Mon Jan 14 2008 lars@linux-schulserver.de
- initial package 0.0.9
